#include "texthighlighter.h"
#include <QTextCharFormat>
#include <QBrush>
#include <QColor>

TextHighLighter::TextHighLighter(QTextDocument *parent) : QSyntaxHighlighter(parent)
{
    HighlightingRule rule;

    QStringList keywordPatterns;
    keywordPatterns << "\\bword\\b" << "\\bwill\\b";

    m_format.setForeground(Qt::red);
    m_format.setFontWeight(QFont::Bold);

    for (const QString &pattern : keywordPatterns) {
        rule.pattern = QRegExp(pattern);
        rule.format = m_format;
        m_formatRules.append(rule);
    }
}

void TextHighLighter::highlightBlock(const QString &text)
{
    for (const HighlightingRule &rule : m_formatRules) {
        QRegExp expression(rule.pattern);
        int index = expression.indexIn(text);
        while (index >= 0) {
            int length = expression.matchedLength();
            setFormat(index, length, rule.format);
            index = expression.indexIn(text, index + length);
        }
    }
}
